@@ -6,6 +6,9 @@ class InstrumentExchange:
     instrument: str
     to_instrument: str
 
+    def invert(self):
+        return InstrumentExchange(self.to_instrument, self.instrument)
+
     def __iter__(self):
         return iter((self.instrument, self.to_instrument))
 
